==> scanbot_sdk-2.8.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeScannerResult.swift <==
//
//  SBSDKBarcodeScannerResult.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 04.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeScannerResult {
    var encodedDictionary: [String: Any?] {

        var dictionary: [String: Any?] = ["text": self.rawTextString,
                                          "barcodeFormat": self.type.encodedString,
                                          "rawBytes": self.rawBytes.base64EncodedString()]

        if let parsedResult = self.parsedFormattedResult {
            var updatedResult = parsedResult
            updatedResult["parsedSuccessful"] = self.formattedResult.parsedSuccessful
            dictionary["formattedResult"] = updatedResult
        }

        return dictionary
    }

    private var parsedFormattedResult: [String:Any?]? {
        if let formattedResult = self.formattedResult as? SBSDKVCardDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKAAMVADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKIDCardPDF417DocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKSEPADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKDisabilityCertificateDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKBoardingPassDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKMedicalPlanDocumentFormat {
            return formattedResult.encodedDictionary
        }

        return nil
    }
}

==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeScannerResult.swift <==
//
//  SBSDKBarcodeScannerResult.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 04.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeScannerResult {
    var encodedDictionary: [String: Any?] {

        var dictionary: [String: Any?] = ["text": self.rawTextString,
                                          "barcodeFormat": self.type.encodedString,
                                          "rawBytes": self.rawBytes.base64EncodedString()]

        if let parsedResult = self.parsedFormattedResult {
            var updatedResult = parsedResult
            updatedResult["parsedSuccessful"] = self.formattedResult.parsedSuccessful
            dictionary["formattedResult"] = updatedResult
        }

        return dictionary
    }

    private var parsedFormattedResult: [String:Any?]? {
        if let formattedResult = self.formattedResult as? SBSDKVCardDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKAAMVADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKIDCardPDF417DocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKSEPADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKMedicalCertificateDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKBoardingPassDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKMedicalPlanDocumentFormat {
            return formattedResult.encodedDictionary
        }

        return nil
    }
}
